==> killbill-api-0.25-sources.jar: org/killbill/billing/tenant/api/TenantKV.java <==
/*
 * Copyright 2010-2013 Ning, Inc.
 *
 * Ning licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.tenant.api;

import org.killbill.billing.util.entity.Entity;

public interface TenantKV extends Entity {

    public String getKey();

    public String getValue();

    public enum TenantKey {

        // Key for push notification callback
        PUSH_NOTIFICATION_CB(true),
        // Catalog Key
        CATALOG(false),
        // Overdue Configuration Key
        OVERDUE_CONFIG(true),
        // Invoice Translation Key Prefix
        INVOICE_TRANSLATION_(true),
        // Catalog Translation Key Prefix
        CATALOG_TRANSLATION_(true),
        // Invoice Template Key
        INVOICE_TEMPLATE(true),
        // Invoice Template ManualPay Key
        INVOICE_MP_TEMPLATE(true),
        // Plugin config
        PLUGIN_CONFIG_(true);

        private final boolean singleValue;

        TenantKey(final boolean singleValue) {
            this.singleValue = singleValue;
        }

        public boolean isSingleValue() {
            return singleValue;
        }
    }
}

==> killbill-api-0.51.17-sources.jar: org/killbill/billing/tenant/api/TenantKV.java <==
/*
 * Copyright 2010-2014 Ning, Inc.
 * Copyright 2014-2016 Groupon, Inc
 * Copyright 2014-2016 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.tenant.api;

import org.killbill.billing.util.entity.Entity;

public interface TenantKV extends Entity {

    public String getKey();

    public String getValue();

    public enum TenantKey {

        // Key for push notification callback
        PUSH_NOTIFICATION_CB(true),
        // Catalog Key
        CATALOG(false),
        // Overdue Configuration Key
        OVERDUE_CONFIG(true),
        // Per Tenant Configuration Key
        PER_TENANT_CONFIG(true),
        // Invoice Translation Key Prefix
        INVOICE_TRANSLATION_(true),
        // Catalog Translation Key Prefix
        CATALOG_TRANSLATION_(true),
        // Invoice Template Key
        INVOICE_TEMPLATE(true),
        // Invoice Template ManualPay Key
        INVOICE_MP_TEMPLATE(true),
        // Plugin config
        PLUGIN_CONFIG_(true),
        // Plugin payment state machine
        PLUGIN_PAYMENT_STATE_MACHINE_(true);

        private final boolean singleValue;

        TenantKey(final boolean singleValue) {
            this.singleValue = singleValue;
        }

        public boolean isSingleValue() {
            return singleValue;
        }
    }
}
